package com.afp.ordermanagement.service;

import com.afp.ordermanagement.model.Manager;
import com.afp.ordermanagement.repository.ManagerRepository;
import com.google.api.client.googleapis.auth.oauth2.GoogleIdToken;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import reactor.core.publisher.Flux;
import reactor.core.publisher.Mono;

import java.util.Optional;

@Service
public class ManagerService {
    @Autowired
    ManagerRepository managerRepository;

    public Flux<Manager> getAll() {
        return managerRepository.findAll();
    }

    public Mono<Manager> getById(String uuid) {
        return managerRepository.findById(uuid);
    }

    public Mono<Manager> getByEmail(String email) {
        return managerRepository.findByEmail(email);
    }

    public Mono<Manager> create(Manager newManager) {
        return managerRepository.save(newManager);
    }

    public Mono<Manager> updateById(String uuid, Manager managerUpdates) {
        return this.getById(uuid)
                .map(existingManager -> Manager.combine(existingManager, managerUpdates))
                .flatMap(managerRepository::save);
    }

    public Mono<Void> delete(Manager manager) {
        return managerRepository.delete(manager);
    }
}
